==> lire_1.5.orig.tar.gz: lire-1.5/all/lib/tests/po/lire-test.pot.pl <==
# REFERENCE: test-l10n.cfg
__( q{JPEG Files} );
# REFERENCE: schema:test
__( q{Simple Schema Definition for Test} );
# REFERENCE: schema:test
__( q{Simple schema definition for testing purpose} );
# REFERENCE: schema:test
__( q{Start Time} );
# REFERENCE: schema:test
__( q{Start time of the file transfer.} );
# REFERENCE: schema:test
__( q{End Time} );
# REFERENCE: schema:test
__( q{The time at which the transfer ended.} );
# REFERENCE: schema:test
__( q{Duration} );
# REFERENCE: schema:test
__( q{Time taken by the transfer.} );
# REFERENCE: schema:test
__( q{Connection ID} );
# REFERENCE: schema:test
__( q{Connection identifier.
   } );
# REFERENCE: schema:test
__( q{Client Host} );
# REFERENCE: schema:test
__( q{The host to which the file was transferred.} );
# REFERENCE: schema:test
__( q{Username} );
# REFERENCE: schema:test
__( q{Name of the authenticated user that did the file transfer.
   } );
# REFERENCE: schema:test
__( q{File} );
# REFERENCE: schema:test
__( q{The file that was transferred.
   } );
# REFERENCE: schema:test
__( q{Size} );
# REFERENCE: schema:test
__( q{The number of bytes transferred.} );
# REFERENCE: schema:test
__( q{Complete?} );
# REFERENCE: schema:test
__( q{Was the file transferred completely?} );
# REFERENCE: schema:test-extended
__( q{Simple Extended Schema for Tests} );
# REFERENCE: schema:test-extended
__( q{Simple extended schema for testing purpose.} );
# REFERENCE: schema:test-extended
__( q{Directory} );
# REFERENCE: schema:test-extended
__( q{Contains the file's directory.} );
# REFERENCE: report:test:top-files
__( q{Top Files Report Specification} );
# REFERENCE: report:test:top-files
__( q{Test report specification.} );
# REFERENCE: report:test:top-files
__( q{Downloads by File, Top $files_to_show} );
# REFERENCE: report:test:top-files
__( q{Downloads} );
# REFERENCE: report:test:top-files
__( q{% Total} );
# REFERENCE: report:test:top-dirs
__( q{Top Directories Report Specification} );
# REFERENCE: report:test:top-dirs
__( q{Test report specification using an extended schema.} );
# REFERENCE: report:test:top-dirs
__( q{Downloads by Directory, Top $dirs_to_show} );
# REFERENCE: report:test:top-dirs
__( q{Bytes Downloaded} );
# REFERENCE: report:test:top-dirs
__( q{% Total} );
# REFERENCE: filter:test:select-file
__( q{Select File Filter Specification} );
# REFERENCE: filter:test:select-file
__( q{Test global filter specification.
  } );
# REFERENCE: filter:test:select-file
__( q{Test parameter.} );
# REFERENCE: filter:test:select-file
__( q{selected files matching $file_match} );

==> lire_2.1.1.orig.tar.gz: lire-2.1.1/all/lib/tests/po/lire-test.pot.pl <==
# REFERENCE: test-l10n_cfg.xml
__( q{JPEG Files} );
# REFERENCE: schema:test
__( q{Simple Schema Definition for Test} );
# REFERENCE: schema:test
__( q{Simple schema definition for testing purpose} );
# REFERENCE: schema:test
__( q{Start Time} );
# REFERENCE: schema:test
__( q{Start time of the file transfer.} );
# REFERENCE: schema:test
__( q{End Time} );
# REFERENCE: schema:test
__( q{The time at which the transfer ended.} );
# REFERENCE: schema:test
__( q{Duration} );
# REFERENCE: schema:test
__( q{Time taken by the transfer.} );
# REFERENCE: schema:test
__( q{Connection ID} );
# REFERENCE: schema:test
__( q{Connection identifier. } );
# REFERENCE: schema:test
__( q{Client Host} );
# REFERENCE: schema:test
__( q{The host to which the file was transferred.} );
# REFERENCE: schema:test
__( q{Username} );
# REFERENCE: schema:test
__( q{Name of the authenticated user that did the file transfer. } );
# REFERENCE: schema:test
__( q{File} );
# REFERENCE: schema:test
__( q{The file that was transferred. } );
# REFERENCE: schema:test
__( q{Size} );
# REFERENCE: schema:test
__( q{The number of bytes transferred.} );
# REFERENCE: schema:test
__( q{Complete?} );
# REFERENCE: schema:test
__( q{Was the file transferred completely?} );
# REFERENCE: schema:test-extended
__( q{Simple Extended Schema for Tests} );
# REFERENCE: schema:test-extended
__( q{Simple extended schema for testing purpose.} );
# REFERENCE: schema:test-extended
__( q{Directory} );
# REFERENCE: schema:test-extended
__( q{Contains the file's directory.} );
# REFERENCE: report:test:top-files
__( q{Top Files Report Specification} );
# REFERENCE: report:test:top-files
__( q{Test report specification.} );
# REFERENCE: report:test:top-files
__( q{Downloads by File, Top $files_to_show} );
# REFERENCE: report:test:top-files
__( q{Downloads} );
# REFERENCE: report:test:top-files
__( q{% Total} );
# REFERENCE: report:test:top-dirs
__( q{Top Directories Report Specification} );
# REFERENCE: report:test:top-dirs
__( q{Test report specification using an extended schema.} );
# REFERENCE: report:test:top-dirs
__( q{Downloads by Directory, Top $dirs_to_show} );
# REFERENCE: report:test:top-dirs
__( q{Bytes Downloaded} );
# REFERENCE: report:test:top-dirs
__( q{% Total} );
# REFERENCE: filter:test:select-file
__( q{Select File Filter Specification} );
# REFERENCE: filter:test:select-file
__( q{Test global filter specification. } );
# REFERENCE: filter:test:select-file
__( q{Test parameter.} );
# REFERENCE: filter:test:select-file
__( q{selected files matching $file_match} );
